pub struct Request {
pub data: Option<Vec<BufferRegion>>,
pub defer_completion: Option<bool>,
pub information: Option<RequestInfo>,
pub short: Option<bool>,
/* private fields */
}Expand description
Requests passed over fuchsia.hardware.usb.endpoint.Endpoint. See fuchsia.hardware.usb.endpoint.Endpoint::QueueRequests for more details.
Fields
data: Option<Vec<BufferRegion>>Data. This array is consumed in-order, and allows for scatter/gather semantics across physically non-contiguous regions of a large buffer.
defer_completion: Option<bool>Indicates not to complete this Request when done unless it failed. All Requests up to the next defer_completion == false are responded to as one unit.
information: Option<RequestInfo>Extra information needed for Request.
short: Option<bool>True if this is a short transfer sending less than what the receiver is expecting. Controllers ensure this transfer is terminated by a short packet.
Interpreted as false if absent.