pub enum Buffer {
VmoId(u64),
Data(Vec<u8>),
// some variants omitted
}Expand description
Data buffer. There are two supported ways data may be conveyed, corresponding to the two members of the Buffer union:
- vmo_id: Pre-registered VMO. A driver may preregister VMOs using the fuchsia.hardware.usb.endpoint.Endpoint::RegisterVmos method. These VMOs are saved by the underlying USB driver in correspondence to the given vmo_id. Future Requests may refer to this by the unique vmo_id. Because VMOs are reused across Requests and saved by the underlying driver, each VMO only needs to be pinned/unpinned once.
- data: A data buffer for data that is not associated with a VMO. The underlying USB driver should allocate its own VMO, copy the data from the buffer, and pin the VMO. This should not be used often and not for large amounts of data.
Variants
VmoId(u64)
The ID of a VMO that was previously registered.
Data(Vec<u8>)
Embedded data buffer to copy data to/from.
Implementations